| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.Addresses.Insert
Description
Creates an address resource in the specified project using the data included in the request.
See: Compute Engine API Reference for compute.addresses.insert.
- type AddressesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("regions" :> (Capture "region" Text :> ("addresses" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Address :> Post '[JSON] Operation))))))))
- addressesInsert :: Text -> Address -> Text -> AddressesInsert
- data AddressesInsert
- aiProject :: Lens' AddressesInsert Text
- aiPayload :: Lens' AddressesInsert Address
- aiRegion :: Lens' AddressesInsert Text
REST Resource
type AddressesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("regions" :> (Capture "region" Text :> ("addresses" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Address :> Post '[JSON] Operation)))))))) Source #
A resource alias for compute.addresses.insert method which the
AddressesInsert request conforms to.
Creating a Request
Creates a value of AddressesInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data AddressesInsert Source #
Creates an address resource in the specified project using the data included in the request.
See: addressesInsert smart constructor.
Instances