| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.BackendServices.Update
Description
Updates the specified BackendService resource with the data included in the request. There are several restrictions and guidelines to keep in mind when updating a backend service. Read Restrictions and Guidelines for more information.
See: Compute Engine API Reference for compute.backendServices.update.
- type BackendServicesUpdateResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("backendServices" :> (Capture "backendService" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] BackendService :> Put '[JSON] Operation))))))))
- backendServicesUpdate :: Text -> BackendService -> Text -> BackendServicesUpdate
- data BackendServicesUpdate
- bsuProject :: Lens' BackendServicesUpdate Text
- bsuPayload :: Lens' BackendServicesUpdate BackendService
- bsuBackendService :: Lens' BackendServicesUpdate Text
REST Resource
type BackendServicesUpdateResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("backendServices" :> (Capture "backendService" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] BackendService :> Put '[JSON] Operation)))))))) Source #
A resource alias for compute.backendServices.update method which the
BackendServicesUpdate request conforms to.
Creating a Request
backendServicesUpdate Source #
Arguments
| :: Text | |
| -> BackendService | |
| -> Text | |
| -> BackendServicesUpdate |
Creates a value of BackendServicesUpdate with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data BackendServicesUpdate Source #
Updates the specified BackendService resource with the data included in the request. There are several restrictions and guidelines to keep in mind when updating a backend service. Read Restrictions and Guidelines for more information.
See: backendServicesUpdate smart constructor.
Instances
Request Lenses
bsuProject :: Lens' BackendServicesUpdate Text Source #
Project ID for this request.
bsuPayload :: Lens' BackendServicesUpdate BackendService Source #
Multipart request metadata.
bsuBackendService :: Lens' BackendServicesUpdate Text Source #
Name of the BackendService resource to update.