| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.Disks.Get
Description
Returns a specified persistent disk. Get a list of available persistent disks by making a list() request.
See: Compute Engine API Reference for compute.disks.get.
- type DisksGetResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("zones" :> (Capture "zone" Text :> ("disks" :> (Capture "disk" Text :> (QueryParam "alt" AltJSON :> Get '[JSON] Disk))))))))
- disksGet :: Text -> Text -> Text -> DisksGet
- data DisksGet
- dgProject :: Lens' DisksGet Text
- dgDisk :: Lens' DisksGet Text
- dgZone :: Lens' DisksGet Text
REST Resource
type DisksGetResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("zones" :> (Capture "zone" Text :> ("disks" :> (Capture "disk" Text :> (QueryParam "alt" AltJSON :> Get '[JSON] Disk)))))))) Source #
A resource alias for compute.disks.get method which the
DisksGet request conforms to.
Creating a Request
Returns a specified persistent disk. Get a list of available persistent disks by making a list() request.
See: disksGet smart constructor.