| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.Firewalls.Insert
Description
Creates a firewall rule in the specified project using the data included in the request.
See: Compute Engine API Reference for compute.firewalls.insert.
- type FirewallsInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("firewalls" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Firewall :> Post '[JSON] Operation)))))))
- firewallsInsert :: Text -> Firewall -> FirewallsInsert
- data FirewallsInsert
- fiProject :: Lens' FirewallsInsert Text
- fiPayload :: Lens' FirewallsInsert Firewall
REST Resource
type FirewallsInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("firewalls" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Firewall :> Post '[JSON] Operation))))))) Source #
A resource alias for compute.firewalls.insert method which the
FirewallsInsert request conforms to.
Creating a Request
Arguments
| :: Text | |
| -> Firewall | |
| -> FirewallsInsert |
Creates a value of FirewallsInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data FirewallsInsert Source #
Creates a firewall rule in the specified project using the data included in the request.
See: firewallsInsert smart constructor.
Instances