| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.ForwardingRules.Insert
Description
Creates a ForwardingRule resource in the specified project and region using the data included in the request.
See: Compute Engine API Reference for compute.forwardingRules.insert.
- type ForwardingRulesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("regions" :> (Capture "region" Text :> ("forwardingRules" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] ForwardingRule :> Post '[JSON] Operation))))))))
- forwardingRulesInsert :: Text -> ForwardingRule -> Text -> ForwardingRulesInsert
- data ForwardingRulesInsert
- friProject :: Lens' ForwardingRulesInsert Text
- friPayload :: Lens' ForwardingRulesInsert ForwardingRule
- friRegion :: Lens' ForwardingRulesInsert Text
REST Resource
type ForwardingRulesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("regions" :> (Capture "region" Text :> ("forwardingRules" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] ForwardingRule :> Post '[JSON] Operation)))))))) Source #
A resource alias for compute.forwardingRules.insert method which the
ForwardingRulesInsert request conforms to.
Creating a Request
forwardingRulesInsert Source #
Arguments
| :: Text | |
| -> ForwardingRule | |
| -> Text | |
| -> ForwardingRulesInsert |
Creates a value of ForwardingRulesInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data ForwardingRulesInsert Source #
Creates a ForwardingRule resource in the specified project and region using the data included in the request.
See: forwardingRulesInsert smart constructor.
Instances
Request Lenses
friProject :: Lens' ForwardingRulesInsert Text Source #
Project ID for this request.
friPayload :: Lens' ForwardingRulesInsert ForwardingRule Source #
Multipart request metadata.