| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.ForwardingRules.SetTarget
Description
Changes target URL for forwarding rule. The new target should be of the same type as the old target.
See: Compute Engine API Reference for compute.forwardingRules.setTarget.
- type ForwardingRulesSetTargetResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("regions" :> (Capture "region" Text :> ("forwardingRules" :> (Capture "forwardingRule" Text :> ("setTarget" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] TargetReference :> Post '[JSON] Operation))))))))))
- forwardingRulesSetTarget :: Text -> Text -> TargetReference -> Text -> ForwardingRulesSetTarget
- data ForwardingRulesSetTarget
- frstProject :: Lens' ForwardingRulesSetTarget Text
- frstForwardingRule :: Lens' ForwardingRulesSetTarget Text
- frstPayload :: Lens' ForwardingRulesSetTarget TargetReference
- frstRegion :: Lens' ForwardingRulesSetTarget Text
REST Resource
type ForwardingRulesSetTargetResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("regions" :> (Capture "region" Text :> ("forwardingRules" :> (Capture "forwardingRule" Text :> ("setTarget" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] TargetReference :> Post '[JSON] Operation)))))))))) Source #
A resource alias for compute.forwardingRules.setTarget method which the
ForwardingRulesSetTarget request conforms to.
Creating a Request
forwardingRulesSetTarget Source #
Arguments
| :: Text | |
| -> Text | |
| -> TargetReference | |
| -> Text | |
| -> ForwardingRulesSetTarget |
Creates a value of ForwardingRulesSetTarget with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data ForwardingRulesSetTarget Source #
Changes target URL for forwarding rule. The new target should be of the same type as the old target.
See: forwardingRulesSetTarget smart constructor.
Instances
Request Lenses
frstProject :: Lens' ForwardingRulesSetTarget Text Source #
Project ID for this request.
frstForwardingRule :: Lens' ForwardingRulesSetTarget Text Source #
Name of the ForwardingRule resource in which target is to be set.
frstPayload :: Lens' ForwardingRulesSetTarget TargetReference Source #
Multipart request metadata.
frstRegion :: Lens' ForwardingRulesSetTarget Text Source #
Name of the region scoping this request.