| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.GlobalForwardingRules.Insert
Description
Creates a ForwardingRule resource in the specified project and region using the data included in the request.
See: Compute Engine API Reference for compute.globalForwardingRules.insert.
- type GlobalForwardingRulesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("forwardingRules" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] ForwardingRule :> Post '[JSON] Operation)))))))
- globalForwardingRulesInsert :: Text -> ForwardingRule -> GlobalForwardingRulesInsert
- data GlobalForwardingRulesInsert
- gfriProject :: Lens' GlobalForwardingRulesInsert Text
- gfriPayload :: Lens' GlobalForwardingRulesInsert ForwardingRule
REST Resource
type GlobalForwardingRulesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("forwardingRules" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] ForwardingRule :> Post '[JSON] Operation))))))) Source #
A resource alias for compute.globalForwardingRules.insert method which the
GlobalForwardingRulesInsert request conforms to.
Creating a Request
globalForwardingRulesInsert Source #
Arguments
| :: Text | |
| -> ForwardingRule | |
| -> GlobalForwardingRulesInsert |
Creates a value of GlobalForwardingRulesInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data GlobalForwardingRulesInsert Source #
Creates a ForwardingRule resource in the specified project and region using the data included in the request.
See: globalForwardingRulesInsert smart constructor.
Instances
Request Lenses
gfriProject :: Lens' GlobalForwardingRulesInsert Text Source #
Project ID for this request.
gfriPayload :: Lens' GlobalForwardingRulesInsert ForwardingRule Source #
Multipart request metadata.