| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.GlobalForwardingRules.SetTarget
Description
Changes target URL for forwarding rule. The new target should be of the same type as the old target.
See: Compute Engine API Reference for compute.globalForwardingRules.setTarget.
- type GlobalForwardingRulesSetTargetResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("forwardingRules" :> (Capture "forwardingRule" Text :> ("setTarget" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] TargetReference :> Post '[JSON] Operation)))))))))
- globalForwardingRulesSetTarget :: Text -> Text -> TargetReference -> GlobalForwardingRulesSetTarget
- data GlobalForwardingRulesSetTarget
- gfrstProject :: Lens' GlobalForwardingRulesSetTarget Text
- gfrstForwardingRule :: Lens' GlobalForwardingRulesSetTarget Text
- gfrstPayload :: Lens' GlobalForwardingRulesSetTarget TargetReference
REST Resource
type GlobalForwardingRulesSetTargetResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("forwardingRules" :> (Capture "forwardingRule" Text :> ("setTarget" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] TargetReference :> Post '[JSON] Operation))))))))) Source #
A resource alias for compute.globalForwardingRules.setTarget method which the
GlobalForwardingRulesSetTarget request conforms to.
Creating a Request
globalForwardingRulesSetTarget Source #
Arguments
| :: Text | |
| -> Text | |
| -> TargetReference | |
| -> GlobalForwardingRulesSetTarget |
Creates a value of GlobalForwardingRulesSetTarget with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data GlobalForwardingRulesSetTarget Source #
Changes target URL for forwarding rule. The new target should be of the same type as the old target.
See: globalForwardingRulesSetTarget smart constructor.
Instances
Request Lenses
gfrstProject :: Lens' GlobalForwardingRulesSetTarget Text Source #
Project ID for this request.
gfrstForwardingRule :: Lens' GlobalForwardingRulesSetTarget Text Source #
Name of the ForwardingRule resource in which target is to be set.
gfrstPayload :: Lens' GlobalForwardingRulesSetTarget TargetReference Source #
Multipart request metadata.