| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.HTTPHealthChecks.Insert
Description
Creates a HttpHealthCheck resource in the specified project using the data included in the request.
See: Compute Engine API Reference for compute.httpHealthChecks.insert.
- type HTTPHealthChecksInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("httpHealthChecks" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] HTTPHealthCheck :> Post '[JSON] Operation)))))))
- hTTPHealthChecksInsert :: Text -> HTTPHealthCheck -> HTTPHealthChecksInsert
- data HTTPHealthChecksInsert
- httphciProject :: Lens' HTTPHealthChecksInsert Text
- httphciPayload :: Lens' HTTPHealthChecksInsert HTTPHealthCheck
REST Resource
type HTTPHealthChecksInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("httpHealthChecks" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] HTTPHealthCheck :> Post '[JSON] Operation))))))) Source #
A resource alias for compute.httpHealthChecks.insert method which the
HTTPHealthChecksInsert request conforms to.
Creating a Request
hTTPHealthChecksInsert Source #
Arguments
| :: Text | |
| -> HTTPHealthCheck | |
| -> HTTPHealthChecksInsert |
Creates a value of HTTPHealthChecksInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data HTTPHealthChecksInsert Source #
Creates a HttpHealthCheck resource in the specified project using the data included in the request.
See: hTTPHealthChecksInsert smart constructor.
Instances
Request Lenses
httphciProject :: Lens' HTTPHealthChecksInsert Text Source #
Project ID for this request.
httphciPayload :: Lens' HTTPHealthChecksInsert HTTPHealthCheck Source #
Multipart request metadata.