| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.HTTPHealthChecks.Update
Description
Updates a HttpHealthCheck resource in the specified project using the data included in the request.
See: Compute Engine API Reference for compute.httpHealthChecks.update.
- type HTTPHealthChecksUpdateResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("httpHealthChecks" :> (Capture "httpHealthCheck" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] HTTPHealthCheck :> Put '[JSON] Operation))))))))
- hTTPHealthChecksUpdate :: Text -> HTTPHealthCheck -> Text -> HTTPHealthChecksUpdate
- data HTTPHealthChecksUpdate
- httphcuProject :: Lens' HTTPHealthChecksUpdate Text
- httphcuPayload :: Lens' HTTPHealthChecksUpdate HTTPHealthCheck
- httphcuHTTPHealthCheck :: Lens' HTTPHealthChecksUpdate Text
REST Resource
type HTTPHealthChecksUpdateResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("httpHealthChecks" :> (Capture "httpHealthCheck" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] HTTPHealthCheck :> Put '[JSON] Operation)))))))) Source #
A resource alias for compute.httpHealthChecks.update method which the
HTTPHealthChecksUpdate request conforms to.
Creating a Request
hTTPHealthChecksUpdate Source #
Arguments
| :: Text | |
| -> HTTPHealthCheck | |
| -> Text | |
| -> HTTPHealthChecksUpdate |
Creates a value of HTTPHealthChecksUpdate with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data HTTPHealthChecksUpdate Source #
Updates a HttpHealthCheck resource in the specified project using the data included in the request.
See: hTTPHealthChecksUpdate smart constructor.
Instances
Request Lenses
httphcuProject :: Lens' HTTPHealthChecksUpdate Text Source #
Project ID for this request.
httphcuPayload :: Lens' HTTPHealthChecksUpdate HTTPHealthCheck Source #
Multipart request metadata.
httphcuHTTPHealthCheck :: Lens' HTTPHealthChecksUpdate Text Source #
Name of the HttpHealthCheck resource to update.