| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.HTTPSHealthChecks.Insert
Description
Creates a HttpsHealthCheck resource in the specified project using the data included in the request.
See: Compute Engine API Reference for compute.httpsHealthChecks.insert.
- type HTTPSHealthChecksInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("httpsHealthChecks" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] HTTPSHealthCheck :> Post '[JSON] Operation)))))))
- httpsHealthChecksInsert :: Text -> HTTPSHealthCheck -> HTTPSHealthChecksInsert
- data HTTPSHealthChecksInsert
- hhciProject :: Lens' HTTPSHealthChecksInsert Text
- hhciPayload :: Lens' HTTPSHealthChecksInsert HTTPSHealthCheck
REST Resource
type HTTPSHealthChecksInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("httpsHealthChecks" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] HTTPSHealthCheck :> Post '[JSON] Operation))))))) Source #
A resource alias for compute.httpsHealthChecks.insert method which the
HTTPSHealthChecksInsert request conforms to.
Creating a Request
httpsHealthChecksInsert Source #
Arguments
| :: Text | |
| -> HTTPSHealthCheck | |
| -> HTTPSHealthChecksInsert |
Creates a value of HTTPSHealthChecksInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data HTTPSHealthChecksInsert Source #
Creates a HttpsHealthCheck resource in the specified project using the data included in the request.
See: httpsHealthChecksInsert smart constructor.
Instances
Request Lenses
hhciProject :: Lens' HTTPSHealthChecksInsert Text Source #
Project ID for this request.
hhciPayload :: Lens' HTTPSHealthChecksInsert HTTPSHealthCheck Source #
Multipart request metadata.