| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.HealthChecks.Delete
Description
Deletes the specified HealthCheck resource.
See: Compute Engine API Reference for compute.healthChecks.delete.
- type HealthChecksDeleteResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("healthChecks" :> (Capture "healthCheck" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Operation)))))))
- healthChecksDelete :: Text -> Text -> HealthChecksDelete
- data HealthChecksDelete
- hcdHealthCheck :: Lens' HealthChecksDelete Text
- hcdProject :: Lens' HealthChecksDelete Text
REST Resource
type HealthChecksDeleteResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("healthChecks" :> (Capture "healthCheck" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Operation))))))) Source #
A resource alias for compute.healthChecks.delete method which the
HealthChecksDelete request conforms to.
Creating a Request
Arguments
| :: Text | |
| -> Text | |
| -> HealthChecksDelete |
Creates a value of HealthChecksDelete with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data HealthChecksDelete Source #
Deletes the specified HealthCheck resource.
See: healthChecksDelete smart constructor.
Request Lenses
hcdHealthCheck :: Lens' HealthChecksDelete Text Source #
Name of the HealthCheck resource to delete.
hcdProject :: Lens' HealthChecksDelete Text Source #
Project ID for this request.