| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.HealthChecks.Insert
Description
Creates a HealthCheck resource in the specified project using the data included in the request.
See: Compute Engine API Reference for compute.healthChecks.insert.
- type HealthChecksInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("healthChecks" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] HealthCheck :> Post '[JSON] Operation)))))))
- healthChecksInsert :: Text -> HealthCheck -> HealthChecksInsert
- data HealthChecksInsert
- hciProject :: Lens' HealthChecksInsert Text
- hciPayload :: Lens' HealthChecksInsert HealthCheck
REST Resource
type HealthChecksInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("healthChecks" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] HealthCheck :> Post '[JSON] Operation))))))) Source #
A resource alias for compute.healthChecks.insert method which the
HealthChecksInsert request conforms to.
Creating a Request
Arguments
| :: Text | |
| -> HealthCheck | |
| -> HealthChecksInsert |
Creates a value of HealthChecksInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data HealthChecksInsert Source #
Creates a HealthCheck resource in the specified project using the data included in the request.
See: healthChecksInsert smart constructor.
Request Lenses
hciProject :: Lens' HealthChecksInsert Text Source #
Project ID for this request.
hciPayload :: Lens' HealthChecksInsert HealthCheck Source #
Multipart request metadata.