| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.Images.Insert
Description
Creates an image in the specified project using the data included in the request.
See: Compute Engine API Reference for compute.images.insert.
- type ImagesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("images" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Image :> Post '[JSON] Operation)))))))
- imagesInsert :: Text -> Image -> ImagesInsert
- data ImagesInsert
- iiProject :: Lens' ImagesInsert Text
- iiPayload :: Lens' ImagesInsert Image
REST Resource
type ImagesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("images" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Image :> Post '[JSON] Operation))))))) Source #
A resource alias for compute.images.insert method which the
ImagesInsert request conforms to.
Creating a Request
Arguments
| :: Text | |
| -> Image | |
| -> ImagesInsert |
Creates a value of ImagesInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data ImagesInsert Source #
Creates an image in the specified project using the data included in the request.
See: imagesInsert smart constructor.
Instances