| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.InstanceGroups.AddInstances
Description
Adds a list of instances to the specified instance group. All of the instances in the instance group must be in the same network/subnetwork. Read Adding instances for more information.
See: Compute Engine API Reference for compute.instanceGroups.addInstances.
- type InstanceGroupsAddInstancesResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("zones" :> (Capture "zone" Text :> ("instanceGroups" :> (Capture "instanceGroup" Text :> ("addInstances" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] InstanceGroupsAddInstancesRequest :> Post '[JSON] Operation))))))))))
- instanceGroupsAddInstances :: Text -> Text -> InstanceGroupsAddInstancesRequest -> Text -> InstanceGroupsAddInstances
- data InstanceGroupsAddInstances
- igaiProject :: Lens' InstanceGroupsAddInstances Text
- igaiZone :: Lens' InstanceGroupsAddInstances Text
- igaiPayload :: Lens' InstanceGroupsAddInstances InstanceGroupsAddInstancesRequest
- igaiInstanceGroup :: Lens' InstanceGroupsAddInstances Text
REST Resource
type InstanceGroupsAddInstancesResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("zones" :> (Capture "zone" Text :> ("instanceGroups" :> (Capture "instanceGroup" Text :> ("addInstances" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] InstanceGroupsAddInstancesRequest :> Post '[JSON] Operation)))))))))) Source #
A resource alias for compute.instanceGroups.addInstances method which the
InstanceGroupsAddInstances request conforms to.
Creating a Request
instanceGroupsAddInstances Source #
Arguments
| :: Text | |
| -> Text | |
| -> InstanceGroupsAddInstancesRequest | |
| -> Text | |
| -> InstanceGroupsAddInstances |
Creates a value of InstanceGroupsAddInstances with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data InstanceGroupsAddInstances Source #
Adds a list of instances to the specified instance group. All of the instances in the instance group must be in the same network/subnetwork. Read Adding instances for more information.
See: instanceGroupsAddInstances smart constructor.
Instances
Request Lenses
igaiProject :: Lens' InstanceGroupsAddInstances Text Source #
Project ID for this request.
igaiZone :: Lens' InstanceGroupsAddInstances Text Source #
The name of the zone where the instance group is located.
igaiPayload :: Lens' InstanceGroupsAddInstances InstanceGroupsAddInstancesRequest Source #
Multipart request metadata.
igaiInstanceGroup :: Lens' InstanceGroupsAddInstances Text Source #
The name of the instance group where you are adding instances.