| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.InstanceTemplates.Insert
Description
Creates an instance template in the specified project using the data that is included in the request. If you are creating a new template to update an existing instance group, your new instance template must use the same network or, if applicable, the same subnetwork as the original template.
See: Compute Engine API Reference for compute.instanceTemplates.insert.
- type InstanceTemplatesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("instanceTemplates" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] InstanceTemplate :> Post '[JSON] Operation)))))))
- instanceTemplatesInsert :: Text -> InstanceTemplate -> InstanceTemplatesInsert
- data InstanceTemplatesInsert
- itiProject :: Lens' InstanceTemplatesInsert Text
- itiPayload :: Lens' InstanceTemplatesInsert InstanceTemplate
REST Resource
type InstanceTemplatesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("instanceTemplates" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] InstanceTemplate :> Post '[JSON] Operation))))))) Source #
A resource alias for compute.instanceTemplates.insert method which the
InstanceTemplatesInsert request conforms to.
Creating a Request
instanceTemplatesInsert Source #
Arguments
| :: Text | |
| -> InstanceTemplate | |
| -> InstanceTemplatesInsert |
Creates a value of InstanceTemplatesInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data InstanceTemplatesInsert Source #
Creates an instance template in the specified project using the data that is included in the request. If you are creating a new template to update an existing instance group, your new instance template must use the same network or, if applicable, the same subnetwork as the original template.
See: instanceTemplatesInsert smart constructor.
Instances
Request Lenses
itiProject :: Lens' InstanceTemplatesInsert Text Source #
Project ID for this request.
itiPayload :: Lens' InstanceTemplatesInsert InstanceTemplate Source #
Multipart request metadata.