| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.Instances.AttachDisk
Description
Attaches a Disk resource to an instance.
See: Compute Engine API Reference for compute.instances.attachDisk.
- type InstancesAttachDiskResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("zones" :> (Capture "zone" Text :> ("instances" :> (Capture "instance" Text :> ("attachDisk" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] AttachedDisk :> Post '[JSON] Operation))))))))))
- instancesAttachDisk :: Text -> Text -> AttachedDisk -> Text -> InstancesAttachDisk
- data InstancesAttachDisk
- iadProject :: Lens' InstancesAttachDisk Text
- iadZone :: Lens' InstancesAttachDisk Text
- iadPayload :: Lens' InstancesAttachDisk AttachedDisk
- iadInstance :: Lens' InstancesAttachDisk Text
REST Resource
type InstancesAttachDiskResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("zones" :> (Capture "zone" Text :> ("instances" :> (Capture "instance" Text :> ("attachDisk" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] AttachedDisk :> Post '[JSON] Operation)))))))))) Source #
A resource alias for compute.instances.attachDisk method which the
InstancesAttachDisk request conforms to.
Creating a Request
Arguments
| :: Text | |
| -> Text | |
| -> AttachedDisk | |
| -> Text | |
| -> InstancesAttachDisk |
Creates a value of InstancesAttachDisk with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data InstancesAttachDisk Source #
Attaches a Disk resource to an instance.
See: instancesAttachDisk smart constructor.
Instances
Request Lenses
iadProject :: Lens' InstancesAttachDisk Text Source #
Project ID for this request.
iadPayload :: Lens' InstancesAttachDisk AttachedDisk Source #
Multipart request metadata.
iadInstance :: Lens' InstancesAttachDisk Text Source #
The instance name for this request.