| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.Instances.Insert
Description
Creates an instance resource in the specified project using the data included in the request.
See: Compute Engine API Reference for compute.instances.insert.
- type InstancesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("zones" :> (Capture "zone" Text :> ("instances" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Instance :> Post '[JSON] Operation))))))))
- instancesInsert :: Text -> Text -> Instance -> InstancesInsert
- data InstancesInsert
- iiiProject :: Lens' InstancesInsert Text
- iiiZone :: Lens' InstancesInsert Text
- iiiPayload :: Lens' InstancesInsert Instance
REST Resource
type InstancesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("zones" :> (Capture "zone" Text :> ("instances" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Instance :> Post '[JSON] Operation)))))))) Source #
A resource alias for compute.instances.insert method which the
InstancesInsert request conforms to.
Creating a Request
Arguments
| :: Text | |
| -> Text | |
| -> Instance | |
| -> InstancesInsert |
Creates a value of InstancesInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data InstancesInsert Source #
Creates an instance resource in the specified project using the data included in the request.
See: instancesInsert smart constructor.
Instances
Request Lenses
iiiProject :: Lens' InstancesInsert Text Source #
Project ID for this request.
iiiPayload :: Lens' InstancesInsert Instance Source #
Multipart request metadata.