| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.Instances.SetMachineType
Description
Changes the machine type for a stopped instance to the machine type specified in the request.
See: Compute Engine API Reference for compute.instances.setMachineType.
- type InstancesSetMachineTypeResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("zones" :> (Capture "zone" Text :> ("instances" :> (Capture "instance" Text :> ("setMachineType" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] InstancesSetMachineTypeRequest :> Post '[JSON] Operation))))))))))
- instancesSetMachineType :: Text -> Text -> InstancesSetMachineTypeRequest -> Text -> InstancesSetMachineType
- data InstancesSetMachineType
- ismtProject :: Lens' InstancesSetMachineType Text
- ismtZone :: Lens' InstancesSetMachineType Text
- ismtPayload :: Lens' InstancesSetMachineType InstancesSetMachineTypeRequest
- ismtInstance :: Lens' InstancesSetMachineType Text
REST Resource
type InstancesSetMachineTypeResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("zones" :> (Capture "zone" Text :> ("instances" :> (Capture "instance" Text :> ("setMachineType" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] InstancesSetMachineTypeRequest :> Post '[JSON] Operation)))))))))) Source #
A resource alias for compute.instances.setMachineType method which the
InstancesSetMachineType request conforms to.
Creating a Request
instancesSetMachineType Source #
Arguments
| :: Text | |
| -> Text | |
| -> InstancesSetMachineTypeRequest | |
| -> Text | |
| -> InstancesSetMachineType |
Creates a value of InstancesSetMachineType with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data InstancesSetMachineType Source #
Changes the machine type for a stopped instance to the machine type specified in the request.
See: instancesSetMachineType smart constructor.
Instances
Request Lenses
ismtProject :: Lens' InstancesSetMachineType Text Source #
Project ID for this request.
ismtPayload :: Lens' InstancesSetMachineType InstancesSetMachineTypeRequest Source #
Multipart request metadata.
ismtInstance :: Lens' InstancesSetMachineType Text Source #
Name of the instance scoping this request.