| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.Instances.SetTags
Description
Sets tags for the specified instance to the data included in the request.
See: Compute Engine API Reference for compute.instances.setTags.
- type InstancesSetTagsResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("zones" :> (Capture "zone" Text :> ("instances" :> (Capture "instance" Text :> ("setTags" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Tags :> Post '[JSON] Operation))))))))))
- instancesSetTags :: Text -> Text -> Tags -> Text -> InstancesSetTags
- data InstancesSetTags
- istProject :: Lens' InstancesSetTags Text
- istZone :: Lens' InstancesSetTags Text
- istPayload :: Lens' InstancesSetTags Tags
- istInstance :: Lens' InstancesSetTags Text
REST Resource
type InstancesSetTagsResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("zones" :> (Capture "zone" Text :> ("instances" :> (Capture "instance" Text :> ("setTags" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Tags :> Post '[JSON] Operation)))))))))) Source #
A resource alias for compute.instances.setTags method which the
InstancesSetTags request conforms to.
Creating a Request
Arguments
| :: Text | |
| -> Text | |
| -> Tags | |
| -> Text | |
| -> InstancesSetTags |
Creates a value of InstancesSetTags with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data InstancesSetTags Source #
Sets tags for the specified instance to the data included in the request.
See: instancesSetTags smart constructor.
Request Lenses
istProject :: Lens' InstancesSetTags Text Source #
Project ID for this request.
istPayload :: Lens' InstancesSetTags Tags Source #
Multipart request metadata.
istInstance :: Lens' InstancesSetTags Text Source #
Name of the instance scoping this request.