| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.Instances.StartWithEncryptionKey
Description
Starts an instance that was stopped using the using the instances().stop method. For more information, see Restart an instance.
See: Compute Engine API Reference for compute.instances.startWithEncryptionKey.
- type InstancesStartWithEncryptionKeyResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("zones" :> (Capture "zone" Text :> ("instances" :> (Capture "instance" Text :> ("startWithEncryptionKey" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] InstancesStartWithEncryptionKeyRequest :> Post '[JSON] Operation))))))))))
- instancesStartWithEncryptionKey :: Text -> Text -> InstancesStartWithEncryptionKeyRequest -> Text -> InstancesStartWithEncryptionKey
- data InstancesStartWithEncryptionKey
- iswekProject :: Lens' InstancesStartWithEncryptionKey Text
- iswekZone :: Lens' InstancesStartWithEncryptionKey Text
- iswekPayload :: Lens' InstancesStartWithEncryptionKey InstancesStartWithEncryptionKeyRequest
- iswekInstance :: Lens' InstancesStartWithEncryptionKey Text
REST Resource
type InstancesStartWithEncryptionKeyResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("zones" :> (Capture "zone" Text :> ("instances" :> (Capture "instance" Text :> ("startWithEncryptionKey" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] InstancesStartWithEncryptionKeyRequest :> Post '[JSON] Operation)))))))))) Source #
A resource alias for compute.instances.startWithEncryptionKey method which the
InstancesStartWithEncryptionKey request conforms to.
Creating a Request
instancesStartWithEncryptionKey Source #
Arguments
| :: Text | |
| -> Text | |
| -> InstancesStartWithEncryptionKeyRequest | |
| -> Text | |
| -> InstancesStartWithEncryptionKey |
Creates a value of InstancesStartWithEncryptionKey with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data InstancesStartWithEncryptionKey Source #
Starts an instance that was stopped using the using the instances().stop method. For more information, see Restart an instance.
See: instancesStartWithEncryptionKey smart constructor.
Instances
Request Lenses
iswekProject :: Lens' InstancesStartWithEncryptionKey Text Source #
Project ID for this request.
iswekZone :: Lens' InstancesStartWithEncryptionKey Text Source #
The name of the zone for this request.
iswekPayload :: Lens' InstancesStartWithEncryptionKey InstancesStartWithEncryptionKeyRequest Source #
Multipart request metadata.
iswekInstance :: Lens' InstancesStartWithEncryptionKey Text Source #
Name of the instance resource to start.