| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.Routers.Insert
Description
Creates a Router resource in the specified project and region using the data included in the request.
See: Compute Engine API Reference for compute.routers.insert.
- type RoutersInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("regions" :> (Capture "region" Text :> ("routers" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Router :> Post '[JSON] Operation))))))))
- routersInsert :: Text -> Router -> Text -> RoutersInsert
- data RoutersInsert
- riProject :: Lens' RoutersInsert Text
- riPayload :: Lens' RoutersInsert Router
- riRegion :: Lens' RoutersInsert Text
REST Resource
type RoutersInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("regions" :> (Capture "region" Text :> ("routers" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Router :> Post '[JSON] Operation)))))))) Source #
A resource alias for compute.routers.insert method which the
RoutersInsert request conforms to.
Creating a Request
Creates a value of RoutersInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data RoutersInsert Source #
Creates a Router resource in the specified project and region using the data included in the request.
See: routersInsert smart constructor.
Instances