| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.Routes.Delete
Description
Deletes the specified Route resource.
See: Compute Engine API Reference for compute.routes.delete.
- type RoutesDeleteResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("routes" :> (Capture "route" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Operation)))))))
- routesDelete :: Text -> Text -> RoutesDelete
- data RoutesDelete
- rdProject :: Lens' RoutesDelete Text
- rdRoute :: Lens' RoutesDelete Text
REST Resource
type RoutesDeleteResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("routes" :> (Capture "route" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Operation))))))) Source #
A resource alias for compute.routes.delete method which the
RoutesDelete request conforms to.
Creating a Request
Arguments
| :: Text | |
| -> Text | |
| -> RoutesDelete |
Creates a value of RoutesDelete with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data RoutesDelete Source #
Deletes the specified Route resource.
See: routesDelete smart constructor.
Instances