| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.Subnetworks.Insert
Description
Creates a subnetwork in the specified project using the data included in the request.
See: Compute Engine API Reference for compute.subnetworks.insert.
- type SubnetworksInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("regions" :> (Capture "region" Text :> ("subnetworks" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Subnetwork :> Post '[JSON] Operation))))))))
- subnetworksInsert :: Text -> Subnetwork -> Text -> SubnetworksInsert
- data SubnetworksInsert
- siProject :: Lens' SubnetworksInsert Text
- siPayload :: Lens' SubnetworksInsert Subnetwork
- siRegion :: Lens' SubnetworksInsert Text
REST Resource
type SubnetworksInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("regions" :> (Capture "region" Text :> ("subnetworks" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] Subnetwork :> Post '[JSON] Operation)))))))) Source #
A resource alias for compute.subnetworks.insert method which the
SubnetworksInsert request conforms to.
Creating a Request
Arguments
| :: Text | |
| -> Subnetwork | |
| -> Text | |
| -> SubnetworksInsert |
Creates a value of SubnetworksInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data SubnetworksInsert Source #
Creates a subnetwork in the specified project using the data included in the request.
See: subnetworksInsert smart constructor.
Request Lenses
siPayload :: Lens' SubnetworksInsert Subnetwork Source #
Multipart request metadata.