| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.TargetHTTPProxies.Delete
Description
Deletes the specified TargetHttpProxy resource.
See: Compute Engine API Reference for compute.targetHttpProxies.delete.
- type TargetHTTPProxiesDeleteResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("targetHttpProxies" :> (Capture "targetHttpProxy" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Operation)))))))
- targetHTTPProxiesDelete :: Text -> Text -> TargetHTTPProxiesDelete
- data TargetHTTPProxiesDelete
- thttppdProject :: Lens' TargetHTTPProxiesDelete Text
- thttppdTargetHTTPProxy :: Lens' TargetHTTPProxiesDelete Text
REST Resource
type TargetHTTPProxiesDeleteResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("targetHttpProxies" :> (Capture "targetHttpProxy" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Operation))))))) Source #
A resource alias for compute.targetHttpProxies.delete method which the
TargetHTTPProxiesDelete request conforms to.
Creating a Request
targetHTTPProxiesDelete Source #
Arguments
| :: Text | |
| -> Text | |
| -> TargetHTTPProxiesDelete |
Creates a value of TargetHTTPProxiesDelete with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data TargetHTTPProxiesDelete Source #
Deletes the specified TargetHttpProxy resource.
See: targetHTTPProxiesDelete smart constructor.
Instances
Request Lenses
thttppdProject :: Lens' TargetHTTPProxiesDelete Text Source #
Project ID for this request.
thttppdTargetHTTPProxy :: Lens' TargetHTTPProxiesDelete Text Source #
Name of the TargetHttpProxy resource to delete.