| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.TargetHTTPSProxies.Delete
Description
Deletes the specified TargetHttpsProxy resource.
See: Compute Engine API Reference for compute.targetHttpsProxies.delete.
- type TargetHTTPSProxiesDeleteResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("targetHttpsProxies" :> (Capture "targetHttpsProxy" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Operation)))))))
- targetHTTPSProxiesDelete :: Text -> Text -> TargetHTTPSProxiesDelete
- data TargetHTTPSProxiesDelete
- thpdProject :: Lens' TargetHTTPSProxiesDelete Text
- thpdTargetHTTPSProxy :: Lens' TargetHTTPSProxiesDelete Text
REST Resource
type TargetHTTPSProxiesDeleteResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("targetHttpsProxies" :> (Capture "targetHttpsProxy" Text :> (QueryParam "alt" AltJSON :> Delete '[JSON] Operation))))))) Source #
A resource alias for compute.targetHttpsProxies.delete method which the
TargetHTTPSProxiesDelete request conforms to.
Creating a Request
targetHTTPSProxiesDelete Source #
Arguments
| :: Text | |
| -> Text | |
| -> TargetHTTPSProxiesDelete |
Creates a value of TargetHTTPSProxiesDelete with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data TargetHTTPSProxiesDelete Source #
Deletes the specified TargetHttpsProxy resource.
See: targetHTTPSProxiesDelete smart constructor.
Instances
Request Lenses
thpdProject :: Lens' TargetHTTPSProxiesDelete Text Source #
Project ID for this request.
thpdTargetHTTPSProxy :: Lens' TargetHTTPSProxiesDelete Text Source #
Name of the TargetHttpsProxy resource to delete.