| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.TargetHTTPSProxies.Insert
Description
Creates a TargetHttpsProxy resource in the specified project using the data included in the request.
See: Compute Engine API Reference for compute.targetHttpsProxies.insert.
- type TargetHTTPSProxiesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("targetHttpsProxies" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] TargetHTTPSProxy :> Post '[JSON] Operation)))))))
- targetHTTPSProxiesInsert :: Text -> TargetHTTPSProxy -> TargetHTTPSProxiesInsert
- data TargetHTTPSProxiesInsert
- thpiProject :: Lens' TargetHTTPSProxiesInsert Text
- thpiPayload :: Lens' TargetHTTPSProxiesInsert TargetHTTPSProxy
REST Resource
type TargetHTTPSProxiesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("targetHttpsProxies" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] TargetHTTPSProxy :> Post '[JSON] Operation))))))) Source #
A resource alias for compute.targetHttpsProxies.insert method which the
TargetHTTPSProxiesInsert request conforms to.
Creating a Request
targetHTTPSProxiesInsert Source #
Arguments
| :: Text | |
| -> TargetHTTPSProxy | |
| -> TargetHTTPSProxiesInsert |
Creates a value of TargetHTTPSProxiesInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data TargetHTTPSProxiesInsert Source #
Creates a TargetHttpsProxy resource in the specified project using the data included in the request.
See: targetHTTPSProxiesInsert smart constructor.
Instances
Request Lenses
thpiProject :: Lens' TargetHTTPSProxiesInsert Text Source #
Project ID for this request.
thpiPayload :: Lens' TargetHTTPSProxiesInsert TargetHTTPSProxy Source #
Multipart request metadata.