| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.TargetHTTPSProxies.SetURLMap
Description
Changes the URL map for TargetHttpsProxy.
See: Compute Engine API Reference for compute.targetHttpsProxies.setUrlMap.
- type TargetHTTPSProxiesSetURLMapResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("targetHttpsProxies" :> (Capture "targetHttpsProxy" Text :> ("setUrlMap" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] URLMapReference :> Post '[JSON] Operation))))))))
- targetHTTPSProxiesSetURLMap :: Text -> URLMapReference -> Text -> TargetHTTPSProxiesSetURLMap
- data TargetHTTPSProxiesSetURLMap
- thpsumProject :: Lens' TargetHTTPSProxiesSetURLMap Text
- thpsumPayload :: Lens' TargetHTTPSProxiesSetURLMap URLMapReference
- thpsumTargetHTTPSProxy :: Lens' TargetHTTPSProxiesSetURLMap Text
REST Resource
type TargetHTTPSProxiesSetURLMapResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("targetHttpsProxies" :> (Capture "targetHttpsProxy" Text :> ("setUrlMap" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] URLMapReference :> Post '[JSON] Operation)))))))) Source #
A resource alias for compute.targetHttpsProxies.setUrlMap method which the
TargetHTTPSProxiesSetURLMap request conforms to.
Creating a Request
targetHTTPSProxiesSetURLMap Source #
Arguments
| :: Text | |
| -> URLMapReference | |
| -> Text | |
| -> TargetHTTPSProxiesSetURLMap |
Creates a value of TargetHTTPSProxiesSetURLMap with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data TargetHTTPSProxiesSetURLMap Source #
Changes the URL map for TargetHttpsProxy.
See: targetHTTPSProxiesSetURLMap smart constructor.
Instances
Request Lenses
thpsumProject :: Lens' TargetHTTPSProxiesSetURLMap Text Source #
Project ID for this request.
thpsumPayload :: Lens' TargetHTTPSProxiesSetURLMap URLMapReference Source #
Multipart request metadata.
thpsumTargetHTTPSProxy :: Lens' TargetHTTPSProxiesSetURLMap Text Source #
Name of the TargetHttpsProxy resource whose URL map is to be set.