| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.TargetSSLProxies.Insert
Description
Creates a TargetSslProxy resource in the specified project using the data included in the request.
See: Compute Engine API Reference for compute.targetSslProxies.insert.
- type TargetSSLProxiesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("targetSslProxies" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] TargetSSLProxy :> Post '[JSON] Operation)))))))
- targetSSLProxiesInsert :: Text -> TargetSSLProxy -> TargetSSLProxiesInsert
- data TargetSSLProxiesInsert
- tspiProject :: Lens' TargetSSLProxiesInsert Text
- tspiPayload :: Lens' TargetSSLProxiesInsert TargetSSLProxy
REST Resource
type TargetSSLProxiesInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("targetSslProxies" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] TargetSSLProxy :> Post '[JSON] Operation))))))) Source #
A resource alias for compute.targetSslProxies.insert method which the
TargetSSLProxiesInsert request conforms to.
Creating a Request
targetSSLProxiesInsert Source #
Arguments
| :: Text | |
| -> TargetSSLProxy | |
| -> TargetSSLProxiesInsert |
Creates a value of TargetSSLProxiesInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data TargetSSLProxiesInsert Source #
Creates a TargetSslProxy resource in the specified project using the data included in the request.
See: targetSSLProxiesInsert smart constructor.
Instances
Request Lenses
tspiProject :: Lens' TargetSSLProxiesInsert Text Source #
Project ID for this request.
tspiPayload :: Lens' TargetSSLProxiesInsert TargetSSLProxy Source #
Multipart request metadata.