| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.TargetVPNGateways.Insert
Description
Creates a target VPN gateway in the specified project and region using the data included in the request.
See: Compute Engine API Reference for compute.targetVpnGateways.insert.
- type TargetVPNGatewaysInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("regions" :> (Capture "region" Text :> ("targetVpnGateways" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] TargetVPNGateway :> Post '[JSON] Operation))))))))
- targetVPNGatewaysInsert :: Text -> TargetVPNGateway -> Text -> TargetVPNGatewaysInsert
- data TargetVPNGatewaysInsert
- tvgiProject :: Lens' TargetVPNGatewaysInsert Text
- tvgiPayload :: Lens' TargetVPNGatewaysInsert TargetVPNGateway
- tvgiRegion :: Lens' TargetVPNGatewaysInsert Text
REST Resource
type TargetVPNGatewaysInsertResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("regions" :> (Capture "region" Text :> ("targetVpnGateways" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] TargetVPNGateway :> Post '[JSON] Operation)))))))) Source #
A resource alias for compute.targetVpnGateways.insert method which the
TargetVPNGatewaysInsert request conforms to.
Creating a Request
targetVPNGatewaysInsert Source #
Arguments
| :: Text | |
| -> TargetVPNGateway | |
| -> Text | |
| -> TargetVPNGatewaysInsert |
Creates a value of TargetVPNGatewaysInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data TargetVPNGatewaysInsert Source #
Creates a target VPN gateway in the specified project and region using the data included in the request.
See: targetVPNGatewaysInsert smart constructor.
Instances
Request Lenses
tvgiProject :: Lens' TargetVPNGatewaysInsert Text Source #
Project ID for this request.
tvgiPayload :: Lens' TargetVPNGatewaysInsert TargetVPNGateway Source #
Multipart request metadata.
tvgiRegion :: Lens' TargetVPNGatewaysInsert Text Source #
Name of the region for this request.