| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.Compute.URLMaps.Update
Description
Updates the specified UrlMap resource with the data included in the request.
See: Compute Engine API Reference for compute.urlMaps.update.
- type URLMapsUpdateResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("urlMaps" :> (Capture "urlMap" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] URLMap :> Put '[JSON] Operation))))))))
- urlMapsUpdate :: Text -> Text -> URLMap -> URLMapsUpdate
- data URLMapsUpdate
- umuURLMap :: Lens' URLMapsUpdate Text
- umuProject :: Lens' URLMapsUpdate Text
- umuPayload :: Lens' URLMapsUpdate URLMap
REST Resource
type URLMapsUpdateResource = "compute" :> ("v1" :> ("projects" :> (Capture "project" Text :> ("global" :> ("urlMaps" :> (Capture "urlMap" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] URLMap :> Put '[JSON] Operation)))))))) Source #
A resource alias for compute.urlMaps.update method which the
URLMapsUpdate request conforms to.
Creating a Request
Arguments
| :: Text | |
| -> Text | |
| -> URLMap | |
| -> URLMapsUpdate |
Creates a value of URLMapsUpdate with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data URLMapsUpdate Source #
Updates the specified UrlMap resource with the data included in the request.
See: urlMapsUpdate smart constructor.
Instances
Request Lenses
umuProject :: Lens' URLMapsUpdate Text Source #
Project ID for this request.
umuPayload :: Lens' URLMapsUpdate URLMap Source #
Multipart request metadata.